GR Reference
------------

Output Functions
^^^^^^^^^^^^^^^^

.. autofunction:: gr.polyline
.. autofunction:: gr.polymarker
.. autofunction:: gr.text
.. autofunction:: gr.fillarea
.. autofunction:: gr.cellarray
.. autofunction:: gr.spline
.. autofunction:: gr.textext
.. autofunction:: gr.inqtextext
.. autofunction:: gr.axes
.. autofunction:: gr.grid
.. autofunction:: gr.verrorbars
.. autofunction:: gr.herrorbars
.. autofunction:: gr.polyline3d
.. autofunction:: gr.axes3d
.. autofunction:: gr.titles3d
.. autofunction:: gr.surface
.. autofunction:: gr.contour
.. autofunction:: gr.drawrect
.. autofunction:: gr.fillrect
.. autofunction:: gr.drawarc
.. autofunction:: gr.fillarc
.. autofunction:: gr.drawarrow
.. autofunction:: gr.drawimage
.. autofunction:: gr.mathtex

Attribute Functions
^^^^^^^^^^^^^^^^^^^

.. autofunction:: gr.setlinetype
.. autofunction:: gr.setlinewidth
.. autofunction:: gr.setlinecolorind
.. autofunction:: gr.setmarkertype
.. autofunction:: gr.setmarkersize
.. autofunction:: gr.setmarkercolorind
.. autofunction:: gr.settextfontprec
.. autofunction:: gr.setcharexpan
.. autofunction:: gr.settextcolorind
.. autofunction:: gr.setcharheight
.. autofunction:: gr.setcharup
.. autofunction:: gr.settextpath
.. autofunction:: gr.settextalign
.. autofunction:: gr.setfillintstyle
.. autofunction:: gr.setfillstyle
.. autofunction:: gr.setfillcolorind
.. autofunction:: gr.setarrowstyle
.. autofunction:: gr.setshadow
.. autofunction:: gr.settransparency

Transformation Functions
^^^^^^^^^^^^^^^^^^^^^^^^

.. autofunction:: gr.setscale
.. autofunction:: gr.inqscale
.. autofunction:: gr.setwindow
.. autofunction:: gr.inqwindow
.. autofunction:: gr.setviewport
.. autofunction:: gr.selntran
.. autofunction:: gr.setclip
.. autofunction:: gr.setwswindow
.. autofunction:: gr.setwsviewport
.. autofunction:: gr.setspace
.. autofunction:: gr.inqspace
.. autofunction:: gr.setcoordxform

Control Functions
^^^^^^^^^^^^^^^^^

.. autofunction:: gr.clearws
.. autofunction:: gr.updatews
.. autofunction:: gr.beginprint
.. autofunction:: gr.beginprintext
.. autofunction:: gr.endprint
.. autofunction:: gr.begingraphics
.. autofunction:: gr.endgraphics
.. autofunction:: gr.setcolorrep
.. autofunction:: gr.updategks
.. autofunction:: gr.opengks
.. autofunction:: gr.closegks
.. autofunction:: gr.inqdspsize
.. autofunction:: gr.openws
.. autofunction:: gr.closews
.. autofunction:: gr.activatews
.. autofunction:: gr.deactivatews
.. autofunction:: gr.emergencyclosegks
